/**
 * Copyright © 2017-2026 Wellington Wallace
 *
 * This file is part of Easy Effects.
 *
 * Easy Effects is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Easy Effects is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
 */

#pragma once

namespace tags::app {

inline constexpr auto minimum_pw_version = "0.3.70";

inline constexpr auto id = "com.github.wwmm.easyeffects";

inline constexpr auto path = "/com/github/wwmm/easyeffects";

inline constexpr auto path_stream_inputs = "/com/github/wwmm/easyeffects/streaminputs/";

inline constexpr auto path_stream_outputs = "/com/github/wwmm/easyeffects/streamoutputs/";

inline constexpr auto flatpak_info_file = "/.flatpak-info";

}  // namespace tags::app
